@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
@@ -15,7 +15,12 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """"dirspec tests."""
 
-from twisted.trial.unittest import TestCase
+from __future__ import unicode_literals, print_function
+
+import os
+
+from operator import setitem
+from testtools.testcase import TestCase
 
 
 class BaseTestCase(TestCase):
@@ -23,8 +28,24 @@ class BaseTestCase(TestCase):
 
     def assert_utf8_bytes(self, value):
         """Check that 'value' is a bytes sequence encoded with utf-8."""
-        self.assertIsInstance(value, str)
+        self.assertIsInstance(value, bytes)
         try:
             value.decode('utf-8')
-        except UnicodeDecodeError:
+        except UnicodeError:
             self.fail('%r should be a utf8 encoded string.' % value)
+
+    def tweak_env(self, envvar, value):
+        """Tweak the environment variable %var to %value.
+
+        Restore the old value when finished.
+        """
+        old_val = os.environ.get(envvar, None)
+
+        if old_val is None:
+            self.addCleanup(os.environ.pop, envvar, None)
+        else:
+            self.addCleanup(setitem, os.environ, envvar, old_val)
+        if value is None:
+            os.environ.pop(envvar, None)
+        else:
+            os.environ[envvar] = value
