@@ -28,15 +28,19 @@ class BasedirTestCase(BaseTestCase):
 
     def test_cache_home(self):
         """Test that XDG_CACHE_HOME is handled correctly."""
-        self.tweak_env('XDG_CACHE_HOME', os.path.abspath(os.path.join(
-                os.getcwd(), '_trial_temp', 'cache')))
+        self.tweak_env('XDG_CACHE_HOME',
+                       os.path.abspath(os.path.join(os.getcwd(),
+                                                    '_trial_temp',
+                                                    'cache')))
         self.assertEqual(os.environ['XDG_CACHE_HOME'].encode('utf-8'),
                          basedir.get_xdg_cache_home())
 
     def test_config_dirs(self):
         """Test that XDG_CONFIG_HOME is handled correctly."""
-        self.tweak_env('XDG_CONFIG_HOME', os.path.abspath(os.path.join(
-                os.getcwd(), '_trial_temp', 'config')))
+        self.tweak_env('XDG_CONFIG_HOME',
+                       os.path.abspath(os.path.join(os.getcwd(),
+                                                    '_trial_temp',
+                                                    'config')))
         self.tweak_env('XDG_CONFIG_DIRS', os.pathsep.join(['etc']))
         self.assertEqual([os.environ['XDG_CONFIG_HOME'].encode('utf-8'),
                           b'etc'],
@@ -44,15 +48,19 @@ class BasedirTestCase(BaseTestCase):
 
     def test_config_home(self):
         """Test that XDG_CONFIG_DIRS is handled correctly."""
-        self.tweak_env('XDG_CONFIG_HOME', os.path.abspath(os.path.join(
-                os.getcwd(), '_trial_temp', 'config')))
+        self.tweak_env('XDG_CONFIG_HOME',
+                       os.path.abspath(os.path.join(os.getcwd(),
+                                                    '_trial_temp',
+                                                    'config')))
         self.assertEqual(os.environ['XDG_CONFIG_HOME'].encode('utf-8'),
                          basedir.get_xdg_config_home())
 
     def test_data_dirs(self):
         """Test that XDG_DATA_HOME is handled correctly."""
-        self.tweak_env('XDG_DATA_HOME', os.path.abspath(os.path.join(
-                os.getcwd(), '_trial_temp', 'xdg_data')))
+        self.tweak_env('XDG_DATA_HOME',
+                       os.path.abspath(os.path.join(os.getcwd(),
+                                                    '_trial_temp',
+                                                    'xdg_data')))
         self.tweak_env('XDG_DATA_DIRS', os.pathsep.join(['foo', 'bar']))
         self.assertEqual([os.environ['XDG_DATA_HOME'].encode('utf-8'),
                           b'foo', b'bar'],
@@ -60,8 +68,10 @@ class BasedirTestCase(BaseTestCase):
 
     def test_data_home(self):
         """Test that XDG_DATA_HOME is handled correctly."""
-        self.tweak_env('XDG_DATA_HOME', os.path.abspath(os.path.join(
-                os.getcwd(), '_trial_temp', 'xdg_data')))
+        self.tweak_env('XDG_DATA_HOME',
+                       os.path.abspath(os.path.join(os.getcwd(),
+                                                    '_trial_temp',
+                                                    'xdg_data')))
         self.assertEqual(os.environ['XDG_DATA_HOME'].encode('utf-8'),
                          basedir.get_xdg_data_home())
 
