@@ -87,7 +87,8 @@ class TestBaseDirectoryWindows(BaseTestCase):
         self.assertEqual(
             special_folders['Local AppData'],
             shell_module.values[FakeShellConModule.CSIDL_LOCAL_APPDATA])
-        self.assertTrue(special_folders['Local AppData'].startswith(
+        self.assertTrue(
+            special_folders['Local AppData'].startswith(
                 special_folders['AppData']))
         self.assertEqual(
             special_folders['Common AppData'],
